"use strict";
var Ps = require("perfect-scrollbar");
var core_1 = require("@angular/core");
var perfect_scrollbar_interfaces_1 = require("./perfect-scrollbar.interfaces");
var PerfectScrollbarComponent = (function () {
    function PerfectScrollbarComponent(elementRef, defaults, differs, zone) {
        this.elementRef = elementRef;
        this.defaults = defaults;
        this.differs = differs;
        this.zone = zone;
        this.hidden = false;
        this.disabled = false;
        this.runInsideAngular = false;
        this.usePSClass = true;
        this.static = false;
        this.outside = false;
    }
    PerfectScrollbarComponent.prototype.ngDoCheck = function () {
        var _this = this;
        if (!this.disabled && this.configDiff) {
            var changes = this.configDiff.diff(this.config || {});
            if (changes) {
                this.ngOnDestroy();
                // Timeout is needed for the styles to update properly
                setTimeout(function () {
                    _this.ngAfterViewInit();
                }, 0);
            }
            else if (this.elementRef.nativeElement) {
                var contentWidth = this.contentWidth;
                var contentHeight = this.contentHeight;
                var width = this.elementRef.nativeElement.offsetWidth;
                var height = this.elementRef.nativeElement.offsetHeight;
                if (this.elementRef.nativeElement.children && this.elementRef.nativeElement.children.length) {
                    contentWidth = this.elementRef.nativeElement.children[0].offsetWidth;
                    contentHeight = this.elementRef.nativeElement.children[0].offsetHeight;
                }
                if (width !== this.width || height !== this.height || contentWidth !== this.contentWidth || contentHeight !== this.contentHeight) {
                    this.width = width;
                    this.height = height;
                    this.contentWidth = contentWidth;
                    this.contentHeight = contentHeight;
                    this.update();
                }
            }
        }
    };
    PerfectScrollbarComponent.prototype.ngOnDestroy = function () {
        var _this = this;
        if (this.runInsideAngular) {
            Ps.destroy(this.elementRef.nativeElement);
        }
        else {
            this.zone.runOutsideAngular(function () {
                Ps.destroy(_this.elementRef.nativeElement);
            });
        }
    };
    PerfectScrollbarComponent.prototype.ngOnChanges = function (changes) {
        if (!this.disabled && this.configDiff) {
            if (changes['hidden'] && !this.hidden) {
                this.update();
            }
            if (changes['disabled'] && !this.disabled) {
                this.ngOnDestroy();
            }
        }
    };
    PerfectScrollbarComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        if (!this.disabled) {
            var config_1 = new perfect_scrollbar_interfaces_1.PerfectScrollbarConfig(this.defaults);
            config_1.assign(this.config);
            if (this.runInsideAngular) {
                Ps.initialize(this.elementRef.nativeElement, config_1);
            }
            else {
                this.zone.runOutsideAngular(function () {
                    Ps.initialize(_this.elementRef.nativeElement, config_1);
                });
            }
            if (!this.configDiff) {
                this.configDiff = this.differs.find(this.config || {}).create(null);
            }
        }
    };
    PerfectScrollbarComponent.prototype.update = function () {
        var _this = this;
        if (!this.disabled) {
            if (this.runInsideAngular) {
                Ps.update(this.elementRef.nativeElement);
            }
            else {
                this.zone.runOutsideAngular(function () {
                    Ps.update(_this.elementRef.nativeElement);
                });
            }
        }
    };
    PerfectScrollbarComponent.prototype.scrollTo = function (x, y) {
        if (!this.disabled) {
            if (y == null) {
                this.elementRef.nativeElement.scrollTop = x;
            }
            else {
                this.elementRef.nativeElement.scrollTop = y;
                this.elementRef.nativeElement.scrollLeft = x;
            }
            this.update();
        }
    };
    PerfectScrollbarComponent.prototype.scrollToTop = function (offset) {
        if (offset === void 0) { offset = 0; }
        if (!this.disabled) {
            this.elementRef.nativeElement.scrollTop = 0 + offset;
            this.update();
        }
    };
    PerfectScrollbarComponent.prototype.scrollToLeft = function (offset) {
        if (offset === void 0) { offset = 0; }
        if (!this.disabled) {
            this.elementRef.nativeElement.scrollLeft = 0 + offset;
            this.update();
        }
    };
    PerfectScrollbarComponent.prototype.scrollToRight = function (offset) {
        if (offset === void 0) { offset = 0; }
        if (!this.disabled) {
            var width = this.elementRef.nativeElement.scrollWidth;
            this.elementRef.nativeElement.scrollLeft = width - offset;
            this.update();
        }
    };
    PerfectScrollbarComponent.prototype.scrollToBottom = function (offset) {
        if (offset === void 0) { offset = 0; }
        if (!this.disabled) {
            var height = this.elementRef.nativeElement.scrollHeight;
            this.elementRef.nativeElement.scrollTop = height - offset;
            this.update();
        }
    };
    return PerfectScrollbarComponent;
}());
PerfectScrollbarComponent.decorators = [
    { type: core_1.Component, args: [{
                selector: 'perfect-scrollbar',
                template: '<div class="ps-content"><ng-content></ng-content></div>',
                styles: ['.ps{-ms-touch-action:auto;touch-action:auto;overflow:hidden!important;-ms-overflow-style:none}@supports (-ms-overflow-style:none){.ps{overflow:auto!important}}@media screen and (-ms-high-contrast:active),(-ms-high-contrast:none){.ps{overflow:auto!important}}.ps.ps--active-x>.ps__scrollbar-x-rail,.ps.ps--active-y>.ps__scrollbar-y-rail{display:block;background-color:transparent}.ps.ps--in-scrolling.ps--x>.ps__scrollbar-x-rail{background-color:#eee;opacity:.9}.ps.ps--in-scrolling.ps--x>.ps__scrollbar-x-rail>.ps__scrollbar-x{background-color:#999;height:11px}.ps.ps--in-scrolling.ps--y>.ps__scrollbar-y-rail{background-color:#eee;opacity:.9}.ps.ps--in-scrolling.ps--y>.ps__scrollbar-y-rail>.ps__scrollbar-y{background-color:#999;width:11px}.ps>.ps__scrollbar-x-rail{display:none;position:absolute;opacity:0;-webkit-transition:background-color .2s linear,opacity .2s linear;-o-transition:background-color .2s linear,opacity .2s linear;-moz-transition:background-color .2s linear,opacity .2s linear;transition:background-color .2s linear,opacity .2s linear;bottom:0;height:15px}.ps>.ps__scrollbar-x-rail>.ps__scrollbar-x{position:absolute;background-color:#aaa;-webkit-border-radius:6px;-moz-border-radius:6px;border-radius:6px;-webkit-transition:background-color .2s linear,height .2s linear,width .2s ease-in-out,-webkit-border-radius .2s ease-in-out;-o-transition:background-color .2s linear,height .2s linear,width .2s ease-in-out,border-radius .2s ease-in-out;-moz-transition:background-color .2s linear,height .2s linear,width .2s ease-in-out,border-radius .2s ease-in-out,-moz-border-radius .2s ease-in-out;transition:background-color .2s linear,height .2s linear,width .2s ease-in-out,border-radius .2s ease-in-out;transition:background-color .2s linear,height .2s linear,width .2s ease-in-out,border-radius .2s ease-in-out,-webkit-border-radius .2s ease-in-out,-moz-border-radius .2s ease-in-out;bottom:2px;height:6px}.ps>.ps__scrollbar-x-rail:active>.ps__scrollbar-x,.ps>.ps__scrollbar-x-rail:hover>.ps__scrollbar-x{height:11px}.ps>.ps__scrollbar-y-rail{display:none;position:absolute;opacity:0;-webkit-transition:background-color .2s linear,opacity .2s linear;-o-transition:background-color .2s linear,opacity .2s linear;-moz-transition:background-color .2s linear,opacity .2s linear;transition:background-color .2s linear,opacity .2s linear;right:0;width:15px}.ps>.ps__scrollbar-y-rail>.ps__scrollbar-y{position:absolute;background-color:#aaa;-webkit-border-radius:6px;-moz-border-radius:6px;border-radius:6px;-webkit-transition:background-color .2s linear,height .2s linear,width .2s ease-in-out,-webkit-border-radius .2s ease-in-out;-o-transition:background-color .2s linear,height .2s linear,width .2s ease-in-out,border-radius .2s ease-in-out;-moz-transition:background-color .2s linear,height .2s linear,width .2s ease-in-out,border-radius .2s ease-in-out,-moz-border-radius .2s ease-in-out;transition:background-color .2s linear,height .2s linear,width .2s ease-in-out,border-radius .2s ease-in-out;transition:background-color .2s linear,height .2s linear,width .2s ease-in-out,border-radius .2s ease-in-out,-webkit-border-radius .2s ease-in-out,-moz-border-radius .2s ease-in-out;right:2px;width:6px}.ps>.ps__scrollbar-y-rail:active>.ps__scrollbar-y,.ps>.ps__scrollbar-y-rail:hover>.ps__scrollbar-y{width:11px}.ps:hover.ps--in-scrolling.ps--x>.ps__scrollbar-x-rail{background-color:#eee;opacity:.9}.ps:hover.ps--in-scrolling.ps--x>.ps__scrollbar-x-rail>.ps__scrollbar-x{background-color:#999;height:11px}.ps:hover.ps--in-scrolling.ps--y>.ps__scrollbar-y-rail{background-color:#eee;opacity:.9}.ps:hover.ps--in-scrolling.ps--y>.ps__scrollbar-y-rail>.ps__scrollbar-y{background-color:#999;width:11px}.ps:hover>.ps__scrollbar-x-rail,.ps:hover>.ps__scrollbar-y-rail{opacity:.6}.ps:hover>.ps__scrollbar-x-rail:hover{background-color:#eee;opacity:.9}.ps:hover>.ps__scrollbar-x-rail:hover>.ps__scrollbar-x{background-color:#999}.ps:hover>.ps__scrollbar-y-rail:hover{background-color:#eee;opacity:.9}.ps:hover>.ps__scrollbar-y-rail:hover>.ps__scrollbar-y{background-color:#999}.ps{position:relative;display:block}.ps[hidden]{display:none}.ps[fxlayout]>.ps-content{display:flex;-webkit-box-flex:1;-ms-flex:1 1 auto;flex:1 1 auto}.ps.ps-static{position:static}.ps.ps-static>.ps__scrollbar-x-rail{left:0!important}.ps.ps-static>.ps__scrollbar-y-rail{top:0!important}.ps.ps-outside.ps--active-x{padding-bottom:24px;margin-bottom:-24px}.ps.ps-outside.ps--active-y{padding-right:24px;margin-right:-24px}.ps.ps-outside>.ps__scrollbar-x-rail{margin:0 8px}.ps.ps-outside>.ps__scrollbar-y-rail{margin:8px 0}'],
                encapsulation: core_1.ViewEncapsulation.None
            },] },
];
/** @nocollapse */
PerfectScrollbarComponent.ctorParameters = function () { return [
    { type: core_1.ElementRef, },
    { type: perfect_scrollbar_interfaces_1.PerfectScrollbarConfig, decorators: [{ type: core_1.Optional },] },
    { type: core_1.KeyValueDiffers, },
    { type: core_1.NgZone, },
]; };
PerfectScrollbarComponent.propDecorators = {
    'hidden': [{ type: core_1.HostBinding, args: ['hidden',] }, { type: core_1.Input },],
    'disabled': [{ type: core_1.Input },],
    'runInsideAngular': [{ type: core_1.Input },],
    'config': [{ type: core_1.Input },],
    'usePSClass': [{ type: core_1.HostBinding, args: ['class.ps',] }, { type: core_1.Input },],
    'static': [{ type: core_1.HostBinding, args: ['class.ps-static',] }, { type: core_1.Input },],
    'outside': [{ type: core_1.HostBinding, args: ['class.ps-outside',] }, { type: core_1.Input },],
};
exports.PerfectScrollbarComponent = PerfectScrollbarComponent;
//# sourceMappingURL=perfect-scrollbar.component.js.map