"use strict";
var Ps = require("perfect-scrollbar");
var core_1 = require("@angular/core");
var perfect_scrollbar_interfaces_1 = require("./perfect-scrollbar.interfaces");
var PerfectScrollbarDirective = (function () {
    function PerfectScrollbarDirective(elementRef, defaults, differs, zone) {
        this.elementRef = elementRef;
        this.defaults = defaults;
        this.differs = differs;
        this.zone = zone;
        this.hidden = false;
        this.disabled = false;
        this.runInsideAngular = false;
        this.usePSClass = true;
    }
    PerfectScrollbarDirective.prototype.ngDoCheck = function () {
        var _this = this;
        if (!this.disabled && this.configDiff) {
            var changes = this.configDiff.diff(this.config || {});
            if (changes) {
                this.ngOnDestroy();
                // Timeout is needed for the styles to update properly
                setTimeout(function () {
                    _this.ngAfterViewInit();
                }, 0);
            }
            else if (this.elementRef.nativeElement) {
                var contentWidth = this.contentWidth;
                var contentHeight = this.contentHeight;
                var width = this.elementRef.nativeElement.offsetWidth;
                var height = this.elementRef.nativeElement.offsetHeight;
                if (this.elementRef.nativeElement.children && this.elementRef.nativeElement.children.length) {
                    contentWidth = this.elementRef.nativeElement.children[0].offsetWidth;
                    contentHeight = this.elementRef.nativeElement.children[0].offsetHeight;
                }
                if (width !== this.width || height !== this.height || contentWidth !== this.contentWidth || contentHeight !== this.contentHeight) {
                    this.width = width;
                    this.height = height;
                    this.contentWidth = contentWidth;
                    this.contentHeight = contentHeight;
                    this.update();
                }
            }
        }
    };
    PerfectScrollbarDirective.prototype.ngOnDestroy = function () {
        var _this = this;
        if (this.runInsideAngular) {
            Ps.destroy(this.elementRef.nativeElement);
        }
        else {
            this.zone.runOutsideAngular(function () {
                Ps.destroy(_this.elementRef.nativeElement);
            });
        }
    };
    PerfectScrollbarDirective.prototype.ngOnChanges = function (changes) {
        if (!this.disabled && this.configDiff) {
            if (changes['hidden'] && !this.hidden) {
                this.update();
            }
            if (changes['disabled'] && !this.disabled) {
                this.ngOnDestroy();
            }
        }
    };
    PerfectScrollbarDirective.prototype.ngAfterViewInit = function () {
        var _this = this;
        if (!this.disabled) {
            var config_1 = new perfect_scrollbar_interfaces_1.PerfectScrollbarConfig(this.defaults);
            config_1.assign(this.config);
            if (this.runInsideAngular) {
                Ps.initialize(this.elementRef.nativeElement, config_1);
            }
            else {
                this.zone.runOutsideAngular(function () {
                    Ps.initialize(_this.elementRef.nativeElement, config_1);
                });
            }
            if (!this.configDiff) {
                this.configDiff = this.differs.find(this.config || {}).create(null);
            }
        }
    };
    PerfectScrollbarDirective.prototype.update = function () {
        var _this = this;
        if (!this.disabled) {
            if (this.runInsideAngular) {
                Ps.update(this.elementRef.nativeElement);
            }
            else {
                this.zone.runOutsideAngular(function () {
                    Ps.update(_this.elementRef.nativeElement);
                });
            }
        }
    };
    PerfectScrollbarDirective.prototype.scrollTo = function (x, y) {
        if (!this.disabled) {
            if (y == null) {
                this.elementRef.nativeElement.scrollTop = x;
            }
            else {
                this.elementRef.nativeElement.scrollTop = y;
                this.elementRef.nativeElement.scrollLeft = x;
            }
            this.update();
        }
    };
    PerfectScrollbarDirective.prototype.scrollToTop = function (offset) {
        if (offset === void 0) { offset = 0; }
        if (!this.disabled) {
            this.elementRef.nativeElement.scrollTop = 0 + offset;
            this.update();
        }
    };
    PerfectScrollbarDirective.prototype.scrollToLeft = function (offset) {
        if (offset === void 0) { offset = 0; }
        if (!this.disabled) {
            this.elementRef.nativeElement.scrollLeft = 0 + offset;
            this.update();
        }
    };
    PerfectScrollbarDirective.prototype.scrollToRight = function (offset) {
        if (offset === void 0) { offset = 0; }
        if (!this.disabled) {
            var width = this.elementRef.nativeElement.scrollWidth;
            this.elementRef.nativeElement.scrollLeft = width - offset;
            this.update();
        }
    };
    PerfectScrollbarDirective.prototype.scrollToBottom = function (offset) {
        if (offset === void 0) { offset = 0; }
        if (!this.disabled) {
            var height = this.elementRef.nativeElement.scrollHeight;
            this.elementRef.nativeElement.scrollTop = height - offset;
            this.update();
        }
    };
    return PerfectScrollbarDirective;
}());
PerfectScrollbarDirective.decorators = [
    { type: core_1.Directive, args: [{
                selector: '[perfect-scrollbar]',
                host: {
                    style: 'position: relative;'
                }
            },] },
];
/** @nocollapse */
PerfectScrollbarDirective.ctorParameters = function () { return [
    { type: core_1.ElementRef, },
    { type: perfect_scrollbar_interfaces_1.PerfectScrollbarConfig, decorators: [{ type: core_1.Optional },] },
    { type: core_1.KeyValueDiffers, },
    { type: core_1.NgZone, },
]; };
PerfectScrollbarDirective.propDecorators = {
    'hidden': [{ type: core_1.HostBinding, args: ['hidden',] }, { type: core_1.Input },],
    'disabled': [{ type: core_1.Input },],
    'runInsideAngular': [{ type: core_1.Input },],
    'config': [{ type: core_1.Input, args: ['perfect-scrollbar',] },],
    'usePSClass': [{ type: core_1.HostBinding, args: ['class.ps',] }, { type: core_1.Input },],
};
exports.PerfectScrollbarDirective = PerfectScrollbarDirective;
//# sourceMappingURL=perfect-scrollbar.directive.js.map